@@ -3,7 +3,7 @@ from .source_span import SourceSpan
 from .source import Source
 from .result import Result
 from .error import ParserError
-from .combinator import combinator, combinator_function
+from .combinator import combinator, combinator_function, Combinator
 from .parser_state import ParserState
 from .run import run, run_safe
 
