@@ -1,24 +1,17 @@
-from typing import Tuple, Union, Any
+from typing import Tuple, Union, Any, Callable
 
-from ore_combinators.combinator import combinator
+from ore_combinators.combinator import combinator, Combinator
 from ore_combinators.error import ParserError
 from ore_combinators.parser_state import ParserState
 from ore_combinators.result import Result
 
 
-class AltError(ParserError):
-    pass
-
-
 class alt(combinator):  # noqa
-    def __init__(self, *combinators: Union[combinator, callable]):
+    def __init__(self, *combinators: Combinator):
         self._combinators = list(combinators)
 
     def __call__(self, state: ParserState) -> Tuple[Any, ParserState]:
         for c in self._combinators:
-            if not isinstance(c, combinator) and not hasattr(c, 'is_combinator'):
-                c = c()
-
             try:
                 result, new_state = c(state)
             except Exception:
@@ -26,4 +19,4 @@ class alt(combinator):  # noqa
 
             return result, new_state
 
-        raise AltError(message='Match not found', position=state.position)
+        raise ParserError(message='Match not found', position=state.position)
