@@ -1,17 +1,13 @@
 from typing import Tuple, Any
 
-from ore_combinators.combinator import combinator
+from ore_combinators.combinator import combinator, Combinator
 from ore_combinators.parser_state import ParserState
 from ore_combinators.result import Result
 from ore_combinators.error import ParserError, EndOfFileError
 
 
-class SequenceError(ParserError):
-    pass
-
-
 class sequence(combinator):   # noqa
-    def __init__(self, *combinators: combinator):
+    def __init__(self, *combinators: Combinator):
         self._combinators = combinators
 
     def __call__(self, state: ParserState) -> Tuple[Any, ParserState]:
@@ -23,7 +19,7 @@ class sequence(combinator):   # noqa
             except EndOfFileError:
                 continue
             except ParserError as e:
-                raise SequenceError(
+                raise ParserError(
                     message="Error while processing sequence",
                     position=state.position,
                     nested_error=e
