@@ -1,17 +1,13 @@
 from typing import Tuple, Any
 
-from ore_combinators.combinator import combinator
+from ore_combinators.combinator import combinator, Combinator
 from ore_combinators.parser_state import ParserState
 from ore_combinators.result import Result
 from ore_combinators.error import ParserError, EndOfFileError
 
 
-class TakeNError(ParserError):
-    pass
-
-
 class take_n(combinator):   # noqa
-    def __init__(self, amount: int, c: combinator):
+    def __init__(self, amount: int, c: Combinator):
         self._amount = amount
         self._combinator = c
 
@@ -27,7 +23,7 @@ class take_n(combinator):   # noqa
             try:
                 result, state = self._combinator(state)
             except ParserError as e:
-                raise TakeNError(message="Can't tale n elements", position=state.position, nested_error=e)
+                raise ParserError(message="Can't tale n elements", position=state.position, nested_error=e)
 
             output.append(result)
 
