@@ -1,4 +1,4 @@
-from typing import Optional
+from typing import Optional, Union
 from ore_combinators.source_position import SourcePosition
 
 
@@ -7,7 +7,7 @@ class ParserError(Exception):
             self,
             message: str,
             position: SourcePosition,
-            nested_error: Optional['ParserError'] = None
+            nested_error: Optional[Union[Exception, 'ParserError']] = None
     ):
         super().__init__(message)
         self._message = message
@@ -18,6 +18,14 @@ class ParserError(Exception):
     def message(self) -> str:
         return self._message
 
+    @property
+    def position(self) -> SourcePosition:
+        return self._position
+
+    @property
+    def nested_error(self) -> Union['ParserError', Exception]:
+        return self._nested_error
+
     def __str__(self):
         return f'{self.__class__.__name__}' \
                f'(' \
